# Packager: Paul Pfeister <ppfeister@fedoraproject.org> (GitHub @ppfeister)

Name:           sherlock-project
Version:        0.15.0
Release:        %mkrel 3
Summary:        Hunt down social media accounts by username across social networks
Group:          Development/Python
License:        MIT
URL:            https://github.com/sherlock-project/sherlock
Source:         %{url}/archive/v%{version}/sherlock-%{version}.tar.gz

Patch0:         0001-Remove-tor.patch

BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  help2man


%description
Hunt down social media accounts by username across 400+ social networks and
websites. New targets are tested and implemented regularly.


%prep
%autosetup -p1 -n sherlock-%{version}

sed -i '/torrequest/d' 'pyproject.toml' # Pending upstream removal

%generate_buildrequires
%pyproject_buildrequires -t -x dev


%build
# Project now uses Poetry and dynamic versioning, so pyproject version is 0
# __init__ is currently the single source of truth for version info
sherlock_version=$(sed -n 's/^__version__ *= *"\([0-9.]*\)"/\1/p' sherlock_project/__init__.py)
sed -r -i "s/^version *= .*?$/version = \"$sherlock_version\"/" pyproject.toml
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files sherlock_project

sed -r -i '1{/^#!/d}' '%{buildroot}%{python3_sitelib}/sherlock_project/__main__.py'
sed -r -i '1{/^#!/d}' '%{buildroot}%{python3_sitelib}/sherlock_project/sherlock.py'

install -d '%{buildroot}%{_mandir}/man1'
PYTHONPATH='%{buildroot}%{python3_sitelib}' help2man \
    --no-info \
    --version-string='%{version}' \
    --name='%{summary}' \
    --output='%{buildroot}%{_mandir}/man1/sherlock.1' \
    '%{buildroot}%{_bindir}/sherlock'


%check
%tox -e offline


%files -f %{pyproject_files}
%license LICENSE
%doc docs/README.md
%{_bindir}/sherlock
%{_mandir}/man1/sherlock.1*



%changelog
* Wed Jul 02 2025 umeabot <umeabot> 0.15.0-3.mga10
+ Revision: 2237670
- Mageia 10 Mass Rebuild

* Fri Feb 28 2025 daviddavid <daviddavid> 0.15.0-2.mga10
+ Revision: 2153642
- rebuild for python 3.13

* Mon Jul 08 2024 daviddavid <daviddavid> 0.15.0-1.mga10
+ Revision: 2080341
- new version: 0.15.0

* Thu Jul 04 2024 daviddavid <daviddavid> 0.14.4-1.mga10
+ Revision: 2079777
- initial package sherlock-project

